@@ -6,21 +6,6 @@
 
 #include "application.h"
 
-#include "audiosettings.h"
-#include "generalsettings.h"
-#include "global.h"
-#include "haruna-version.h"
-#include "informationsettings.h"
-#include "mousesettings.h"
-#include "mpvitem.h"
-#include "mpvpreview.h"
-#include "mpvproperties.h"
-#include "playbacksettings.h"
-#include "playlistsettings.h"
-#include "subtitlessettings.h"
-#include "videosettings.h"
-#include "worker.h"
-
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDesktopServices>
@@ -46,14 +31,38 @@
 #include <KWindowConfig>
 #include <KWindowSystem>
 
+#include <MpvAbstractItem>
+
+#include "audiosettings.h"
+#include "generalsettings.h"
+#include "global.h"
+#include "haruna-version.h"
+#include "informationsettings.h"
+#include "mousesettings.h"
+#include "mpvproperties.h"
+#include "playbacksettings.h"
+#include "playlistsettings.h"
+#include "subtitlessettings.h"
+#include "videosettings.h"
+#include "worker.h"
+
+using namespace Qt::StringLiterals;
+
 Application *Application::instance()
 {
     static Application app;
     return &app;
 }
 
+Application *Application::create(QQmlEngine *, QJSEngine *)
+{
+    QQmlEngine::setObjectOwnership(instance(), QQmlEngine::CppOwnership);
+    return instance();
+}
+
 Application::Application()
-    : m_app(qApp)
+    : QObject{nullptr}
+    , m_app(qApp)
     , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath()))
 #if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
     , m_schemes(new KColorSchemeManager(this))
@@ -69,7 +78,7 @@ Application::Application()
     QObject::connect(m_appEventFilter.get(), &ApplicationEventFilter::applicationMouseLeave, this, &Application::qmlApplicationMouseLeave);
     QObject::connect(m_appEventFilter.get(), &ApplicationEventFilter::applicationMouseEnter, this, &Application::qmlApplicationMouseEnter);
 
-    if (GeneralSettings::guiStyle() != QStringLiteral("System")) {
+    if (GeneralSettings::guiStyle() != u"System"_s) {
         QApplication::setStyle(GeneralSettings::guiStyle());
     }
 
@@ -100,21 +109,50 @@ void Application::setupWorkerThread()
 
 void Application::setupAboutData()
 {
-    KAboutData m_aboutData;
-    m_aboutData.setComponentName(QStringLiteral("haruna"));
+    m_aboutData.setComponentName(u"haruna"_s);
     m_aboutData.setDisplayName(i18nc("application title/display name", "Haruna"));
     m_aboutData.setVersion(Application::version().toUtf8());
     m_aboutData.setShortDescription(i18nc("@title", "Media player"));
     m_aboutData.setLicense(KAboutLicense::GPL_V3);
-    m_aboutData.setCopyrightStatement(i18nc("copyright statement", "(c) 2019-2023"));
-    m_aboutData.setHomepage(QStringLiteral("https://haruna.kde.org"));
-    m_aboutData.setBugAddress(QStringLiteral("https://bugs.kde.org/enter_bug.cgi?product=Haruna").toUtf8());
-    m_aboutData.setDesktopFileName(QStringLiteral("org.kde.haruna"));
+    m_aboutData.setCopyrightStatement(i18nc("copyright statement", "(c) 2019-2025"));
+    m_aboutData.setHomepage(u"https://haruna.kde.org"_s);
+    m_aboutData.setBugAddress(u"https://bugs.kde.org/enter_bug.cgi?product=Haruna"_s.toUtf8());
+    m_aboutData.setDesktopFileName(u"org.kde.haruna"_s);
 
     m_aboutData.addAuthor(i18nc("@info:credit", "George Florea Bănuș"),
                           i18nc("@info:credit", "Developer"),
-                          QStringLiteral("georgefb899@gmail.com"),
-                          QStringLiteral("https://georgefb.com"));
+                          u"georgefb899@gmail.com"_s,
+                          u"https://georgefb.com"_s);
+
+    KAboutData::setApplicationData(m_aboutData);
+
+    m_ytdlpProcess = std::make_unique<QProcess>();
+    m_ytdlpProcess->setProgram(Application::youtubeDlExecutable());
+    m_ytdlpProcess->setArguments({u"--version"_s});
+    m_ytdlpProcess->start();
+    connect(m_ytdlpProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [this](int, QProcess::ExitStatus) {
+        auto ytdlpVersion = m_ytdlpProcess->readAllStandardOutput();
+        m_aboutData.addComponent(u"yt-dlp"_s,
+                                 i18n("Feature-rich command-line audio/video downloader"),
+                                 QString::fromUtf8(ytdlpVersion),
+                                 u"https://github.com/yt-dlp/yt-dlp"_s,
+                                 u"https://unlicense.org"_s);
+
+        KAboutData::setApplicationData(m_aboutData);
+    });
+
+    MpvAbstractItem mpvItem;
+    m_aboutData.addComponent(u"mpv"_s,
+                             i18n("Command line video player"),
+                             mpvItem.getProperty(u"mpv-version"_s).toString().replace(u"mpv "_s, QString{}),
+                             u"https://mpv.io"_s,
+                             KAboutLicense::GPL);
+
+    m_aboutData.addComponent(u"ffmpeg"_s,
+                             i18n("Cross-platform solution to record, convert and stream audio and video"),
+                             mpvItem.getProperty(u"ffmpeg-version"_s).toString(),
+                             u"https://www.ffmpeg.org"_s,
+                             KAboutLicense::GPL);
 
     KAboutData::setApplicationData(m_aboutData);
 }
@@ -123,9 +161,9 @@ void Application::setupCommandLineParser()
 {
     m_parser = std::make_unique<QCommandLineParser>();
     m_aboutData.setupCommandLine(m_parser.get());
-    m_parser->addPositionalArgument(QStringLiteral("file"), i18nc("@info:shell", "File to open"));
+    m_parser->addPositionalArgument(u"file"_s, i18nc("@info:shell", "File to open"));
 
-    QCommandLineOption ytdlFormatSelectionOption(QStringList() << QStringLiteral("ytdl-format-selection") << QStringLiteral("ytdlfs"),
+    QCommandLineOption ytdlFormatSelectionOption(QStringList() << u"ytdl-format-selection"_s << u"ytdlfs"_s,
                                                  i18nc("@info:shell",
                                                        "Allows to temporarily override the ytdl format selection setting. "
                                                        "Will be overwritten if the setting is changed through the GUI"),
@@ -159,8 +197,8 @@ void Application::restoreWindowGeometry(QQuickWindow *window) const
     if (!GeneralSettings::rememberWindowGeometry()) {
         return;
     }
-    KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
+    KConfig dataResource(u"data"_s, KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+    KConfigGroup windowGroup(&dataResource, u"Window"_s);
     KWindowConfig::restoreWindowSize(window, windowGroup);
     KWindowConfig::restoreWindowPosition(window, windowGroup);
 }
@@ -228,7 +266,7 @@ bool Application::configFolderExists()
 
 QString Application::version()
 {
-    return QStringLiteral(HARUNA_VERSION_STRING);
+    return QString::fromStdString(HARUNA_VERSION_STRING);
 }
 
 bool Application::hasYoutubeDl()
@@ -238,12 +276,12 @@ bool Application::hasYoutubeDl()
 
 QString Application::youtubeDlExecutable()
 {
-    auto ytDlp = QStandardPaths::findExecutable(QStringLiteral("yt-dlp"));
+    auto ytDlp = QStandardPaths::findExecutable(u"yt-dlp"_s);
     if (!ytDlp.isEmpty()) {
         return ytDlp;
     }
 
-    auto youtubeDl = QStandardPaths::findExecutable(QStringLiteral("youtube-dl"));
+    auto youtubeDl = QStandardPaths::findExecutable(u"youtube-dl"_s);
     if (!youtubeDl.isEmpty()) {
         return youtubeDl;
     }
@@ -264,14 +302,14 @@ QUrl Application::parentUrl(const QString &path)
         fileInfo.setFile(url.toString());
     }
     QUrl parentFolderUrl(fileInfo.absolutePath());
-    parentFolderUrl.setScheme(QStringLiteral("file"));
+    parentFolderUrl.setScheme(u"file"_s);
 
     return parentFolderUrl;
 }
 
 bool Application::isYoutubePlaylist(const QString &path)
 {
-    return path.contains(QStringLiteral("youtube.com/playlist?list"));
+    return path.contains(u"youtube.com/playlist?list"_s);
 }
 
 QString Application::formatTime(const double time)
@@ -281,17 +319,21 @@ QString Application::formatTime(const double time)
     int minutes = (totalNumberOfSeconds / 60) % 60;
     int hours = (totalNumberOfSeconds / 60 / 60);
 
-    QString hoursString = QStringLiteral("%1").arg(hours, 2, 10, QLatin1Char('0'));
-    QString minutesString = QStringLiteral("%1").arg(minutes, 2, 10, QLatin1Char('0'));
-    QString secondsString = QStringLiteral("%1").arg(seconds, 2, 10, QLatin1Char('0'));
-    QString timeString = QStringLiteral("%1:%2:%3").arg(hoursString, minutesString, secondsString);
+    QString hoursString = u"%1"_s.arg(hours, 2, 10, QLatin1Char('0'));
+    QString minutesString = u"%1"_s.arg(minutes, 2, 10, QLatin1Char('0'));
+    QString secondsString = u"%1"_s.arg(seconds, 2, 10, QLatin1Char('0'));
+    QString timeString = u"%1:%2:%3"_s.arg(hoursString, minutesString, secondsString);
 
     return timeString;
 }
 
 QUrl Application::url(int key)
 {
-    return m_urls[key];
+    if (m_urls.contains(key)) {
+        return m_urls[key];
+    }
+
+    return {};
 }
 
 void Application::addUrl(int key, const QString &value)
@@ -331,7 +373,7 @@ QStringList Application::availableGuiStyles()
 
 void Application::setGuiStyle(const QString &style)
 {
-    if (style == QStringLiteral("Default")) {
+    if (style == u"Default"_s) {
         QApplication::setStyle(m_systemDefaultStyle);
         return;
     }
@@ -390,11 +432,15 @@ void Application::raiseWindow()
         return;
     }
 
-    // todo: replace deprecated methods
     QWindow *window = qobject_cast<QWindow *>(m_rootObject);
     if (window) {
         KWindowSystem::activateWindow(window);
     }
 }
 
+bool Application::isPlatformWayland()
+{
+    return KWindowSystem::isPlatformWayland();
+}
+
 #include "moc_application.cpp"
